@@ -1,5 +1,6 @@
 // Copyright 2022 Intel Corporation
 // SPDX-License-Identifier: Apache-2.0
+#ifdef OSPRAY_ENABLE_VOLUMES
 
 #pragma once
 
@@ -24,10 +25,13 @@ struct Isosurfaces
       : isovalues(nullptr),
         volumetricModel(nullptr),
         volume(nullptr),
-        vklHitContext(nullptr)
-  {}
+        vklHitContext(VKLHitIteratorContext())
+  {
+    super.type = ispc::GEOMETRY_TYPE_ISOSURFACES;
+  }
 };
 } // namespace ispc
 #else
 };
 #endif // __cplusplus
+#endif
