@@ -11,9 +11,9 @@ namespace ospray {
  *  thus projects parallel rays of light across the entire scene */
 struct OSPRAY_SDK_INTERFACE DirectionalLight : public Light
 {
-  DirectionalLight() = default;
+  DirectionalLight(api::ISPCDevice &device) : Light(device) {}
   virtual ~DirectionalLight() override = default;
-  virtual ispc::Light *createSh(
+  virtual ISPCRTMemoryView createSh(
       uint32_t, const ispc::Instance *instance = nullptr) const override;
   virtual std::string toString() const override;
   virtual void commit() override;
