@@ -3,8 +3,9 @@
 
 #pragma once
 
-#include "common/Managed.h"
-#include "common/Util.h"
+#include "ISPCDeviceObject.h"
+#include "common/ObjectFactory.h"
+#include "ispcrt.h"
 
 namespace ispc {
 struct Light;
@@ -14,17 +15,15 @@ struct Instance;
 namespace ospray {
 
 //! Base class for Light objects
-struct OSPRAY_SDK_INTERFACE Light : public ManagedObject
+struct OSPRAY_SDK_INTERFACE Light
+    : public ISPCDeviceObject,
+      public ObjectFactory<Light, api::ISPCDevice &>
 {
-  Light();
+  Light(api::ISPCDevice &device);
   virtual ~Light() override = default;
 
-  static Light *createInstance(const char *type);
-  template <typename T>
-  static void registerType(const char *type);
-
   virtual uint32_t getShCount() const;
-  virtual ispc::Light *createSh(
+  virtual ISPCRTMemoryView createSh(
       uint32_t index, const ispc::Instance *instance = nullptr) const = 0;
   virtual void commit() override;
   virtual std::string toString() const override;
@@ -35,11 +34,6 @@ struct OSPRAY_SDK_INTERFACE Light : public ManagedObject
 
  protected:
   void queryIntensityQuantityType(const OSPIntensityQuantity &defaultIQ);
-
- private:
-  template <typename BASE_CLASS, typename CHILD_CLASS>
-  friend void registerTypeHelper(const char *type);
-  static void registerType(const char *type, FactoryFcn<Light> f);
 };
 
 OSPTYPEFOR_SPECIALIZATION(Light *, OSP_LIGHT);
@@ -51,10 +45,4 @@ inline uint32_t Light::getShCount() const
   return 1;
 }
 
-template <typename T>
-inline void Light::registerType(const char *type)
-{
-  registerTypeHelper<Light, T>(type);
-}
-
 } // namespace ospray
