@@ -12,9 +12,9 @@ namespace ospray {
  *  cone of directions bounded by halfAngle */
 struct OSPRAY_SDK_INTERFACE SpotLight : public Light
 {
-  SpotLight() = default;
+  SpotLight(api::ISPCDevice &device) : Light(device) {}
   virtual ~SpotLight() override = default;
-  virtual ispc::Light *createSh(
+  virtual ISPCRTMemoryView createSh(
       uint32_t, const ispc::Instance *instance = nullptr) const override;
   virtual std::string toString() const override;
   virtual void commit() override;
