@@ -15,6 +15,7 @@ namespace ospray {
 
 struct PathTracer : public AddStructShared<Renderer, ispc::PathTracer>
 {
+  PathTracer(api::ISPCDevice &device);
   virtual std::string toString() const override;
   virtual void commit() override;
   virtual void *beginFrame(FrameBuffer *, World *) override;
@@ -23,7 +24,12 @@ struct PathTracer : public AddStructShared<Renderer, ispc::PathTracer>
       Camera *camera,
       World *world,
       void *perFrameData,
-      const utility::ArrayView<uint32_t> &taskIDs) const override;
+      const utility::ArrayView<uint32_t> &taskIDs
+#ifdef OSPRAY_TARGET_SYCL
+      ,
+      sycl::queue &syclQueue
+#endif
+  ) const override;
 
  private:
   void generateGeometryLights(const World &, std::vector<ispc::Light *> &);
