@@ -1,19 +1,24 @@
 // Copyright 2009 Intel Corporation
 // SPDX-License-Identifier: Apache-2.0
+#ifdef OSPRAY_ENABLE_VOLUMES
 
 #pragma once
 
 #include "Volume.h"
 #include "openvkl/openvkl.h"
+// comment break to prevent clang-format from reordering openvkl includes
+#if OPENVKL_VERSION_MAJOR > 1
+#include "openvkl/device/openvkl.h"
+#endif
 // ispc shared
 #include "volume/VolumetricModelShared.h"
 
 namespace ospray {
 
 struct OSPRAY_SDK_INTERFACE VolumetricModel
-    : public AddStructShared<ManagedObject, ispc::VolumetricModel>
+    : public AddStructShared<ISPCDeviceObject, ispc::VolumetricModel>
 {
-  VolumetricModel(Volume *geometry);
+  VolumetricModel(api::ISPCDevice &device, Volume *geometry);
   ~VolumetricModel() override;
   std::string toString() const override;
 
@@ -29,9 +34,10 @@ struct OSPRAY_SDK_INTERFACE VolumetricModel
   box3f volumeBounds;
   Ref<Volume> volume;
   const Ref<Volume> volumeAPI;
-  VKLIntervalIteratorContext vklIntervalContext{nullptr};
+  VKLIntervalIteratorContext vklIntervalContext = VKLIntervalIteratorContext();
 };
 
 OSPTYPEFOR_SPECIALIZATION(VolumetricModel *, OSP_VOLUMETRIC_MODEL);
 
 } // namespace ospray
+#endif
