@@ -3,12 +3,12 @@
 
 #pragma once
 
-#include "../../fb/DistributedFrameBuffer.h"
-#include "../../fb/TileOperation.h"
 #include "camera/Camera.h"
+#include "fb/DistributedFrameBuffer.h"
+#include "fb/TileOperation.h"
 #include "render/Renderer.h"
 // ispc shared
-#include "DistributedRendererShared.h"
+#include "render/RendererShared.h"
 
 namespace ospray {
 namespace mpi {
@@ -22,10 +22,9 @@ struct RegionInfo
   uint8_t *regionVisible = nullptr;
 };
 
-struct DistributedRenderer
-    : public AddStructShared<Renderer, ispc::DistributedRenderer>
+struct DistributedRenderer : public AddStructShared<Renderer, ispc::Renderer>
 {
-  DistributedRenderer();
+  DistributedRenderer(api::ISPCDevice &device);
   ~DistributedRenderer() override;
 
   void computeRegionVisibility(SparseFrameBuffer *fb,
@@ -33,14 +32,38 @@ struct DistributedRenderer
       DistributedWorld *world,
       uint8_t *regionVisible,
       void *perFrameData,
-      const utility::ArrayView<uint32_t> &taskIDs) const;
+      const utility::ArrayView<uint32_t> &taskIDs
+#ifdef OSPRAY_TARGET_SYCL
+      ,
+      sycl::queue &syclQueue
+#endif
+  ) const;
 
-  void renderRegionTasks(SparseFrameBuffer *fb,
+#ifndef OSPRAY_TARGET_SYCL
+  virtual void renderRegionTasks(SparseFrameBuffer *fb,
       Camera *camera,
       DistributedWorld *world,
       const box3f &region,
       void *perFrameData,
-      const utility::ArrayView<uint32_t> &taskIDs) const;
+      const utility::ArrayView<uint32_t> &taskIDs) const = 0;
+#else
+  // Not used by distributed renderers
+  void renderTasks(FrameBuffer *fb,
+      Camera *camera,
+      World *world,
+      void *perFrameData,
+      const utility::ArrayView<uint32_t> &taskIDs,
+      sycl::queue &syclQueue) const override
+  {}
+
+  virtual void renderRegionTasks(SparseFrameBuffer *fb,
+      Camera *camera,
+      DistributedWorld *world,
+      const box3f &region,
+      void *perFrameData,
+      const utility::ArrayView<uint32_t> &taskIDs,
+      sycl::queue &syclQueue) const = 0;
+#endif
 
   virtual std::shared_ptr<TileOperation> tileOperation() = 0;
 
